MethodChannelBdChatSdk class

An implementation of BdChatSdkPlatform that uses method channels.

Inheritance

Constructors

MethodChannelBdChatSdk()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyCustomFontFamilyInAndroid(String regular, String medium, String semiBold, String bold) Future<void>
override
applyCustomFontFamilyInIOS(String fontFamily) Future<void>
override
applyTheme({String? appbarColor, String? accentColor, String? backgroundColor, String? stickyButtonColor}) Future<void>
override
clearSession() Future<void>
override
closeChat() Future<void>
override
configure(String appKey, String brandUrl, [String? culture]) Future<void>
override
disablePushNotification() Future<void>
override
enableLogging() Future<void>
override
enablePushNotification(String fcmToken) Future<void>
override
handleAndroidNotification(Map<String, dynamic> body, String notificationIconPath) Future<void>
override
handleiOSPushNotification(Map<String, dynamic> messageData) Future<bool>
override
isFromChatSDK(Map<String, dynamic> messageData) Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setPreferredTheme(String theme) Future<void>
override
setPrefillFields({String? name, String? email, String? phoneNumber, Map<String, Object?>? chatFields}) Future<void>
override
setSystemFontSize(bool enable) Future<void>
override
setUserToken(String userToken) Future<void>
override
showChat() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited