- Inheritance
-
- Object
- PlatformInterface
- BdChatSdkPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyCustomFontFamilyInAndroid(String regular, String medium, String semiBold, String bold)
→ Future<void>
-
-
applyCustomFontFamilyInIOS(String fontFamily)
→ Future<void>
-
-
applyTheme({String? appbarColor, String? accentColor, String? backgroundColor, String? stickyButtonColor})
→ Future<void>
-
-
clearSession()
→ Future<void>
-
-
closeChat()
→ Future<void>
-
-
configure(String appKey, String brandUrl, [String? culture])
→ Future<void>
-
-
disablePushNotification()
→ Future<void>
-
-
enableLogging()
→ Future<void>
-
-
enablePushNotification(String fcmToken)
→ Future<void>
-
-
handleAndroidNotification(Map<String, dynamic> body, String notificationIconPath)
→ Future<void>
-
-
handleiOSPushNotification(Map<String, dynamic> messageData)
→ Future<bool>
-
-
isFromChatSDK(Map<String, dynamic> messageData)
→ Future<bool>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setPreferredTheme(String theme)
→ Future<void>
-
-
setPrefillFields({String? name, String? email, String? phoneNumber, Map<String, Object?>? chatFields})
→ Future<void>
-
-
setSystemFontSize(bool enable)
→ Future<void>
-
-
setUserToken(String userToken)
→ Future<void>
-
-
showChat()
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited